#!/bin/bash
# Some parameters
E_NOARG=1
E_NODIR=2
DB_USER=madagascar
DB_PW=mirana
DB_OWNER=madagascar
EXCEL2DB=../Excel2DB/loaddb.jar
SHAPEFILES=shapefiles
# SRID=-1
SRID=4326 # pour Antontona
# SRID=32739 # pour Beririninina

# Check arguments
if [ $# -eq 0 ] 
then
    echo "Usage: loaddb [-u|--user <user>] [-p|--passwd <passwd>] [-o|--owner <owner>] [-s|--srid <srid>] <dirname>"
	echo "Two things to do before:"
	echo "1) create a role "madagascar" with password "mirana" as superuser (for postgis) and the ability to create databases"
	echo "2) the directory name must be written without / at the end!"
    exit $E_NOARG
fi

# Setup postgres installation
if [ -z "$POSTGRES_HOME" ]
then
    echo "Warning: POSTGRES_HOME should be defined, default taken."
    POSTGRES_HOME=/usr/local/pgsql
fi
POSTGRES_BIN=$POSTGRES_HOME/bin
POSTGIS=$POSTGRES_HOME/share/contrib/postgis-1.5

while [ $# -gt 0 ]; do    # Until you run out of parameters . . .
  case "$1" in
    -u|--user)
              DB_USER="$2"
	      DB_OWNER="$2"
	      shift
              ;;
    -p|--passwd)
              DB_PW="$2"
	      shift
              ;;
    -o|--owner)
              DB_OWNER="$2"
	      shift
              ;;
    -s|--srid)
              SRID="$2"
	      shift
              ;;
    *)
              DIR="$1"
              shift
              if [ ! -e $DIR ]; then
                echo "Error: Supplied directory doesn't exist!"
                exit $E_NODIR
              fi
              ;;
  esac
  shift       # Check next set of parameters.
done

# Change directory
cd $DIR || {
   echo "Cannot change to directory $DIR">&2
   exit $E_NODIR
}
echo "Go to `pwd`"

# Create the database
echo "Creating $DIR database..."
$POSTGRES_BIN/dropdb -U $DB_USER $DIR
$POSTGRES_BIN/createdb -U $DB_USER -O $DB_OWNER $DIR
# no longer necessary fo postgresql 9.x
# $POSTGRES_BIN/createlang -U $DB_USER plpgsql $DIR
$POSTGRES_BIN/psql -U $DB_USER -d $DIR -f $POSTGIS/postgis.sql
$POSTGRES_BIN/psql -U $DB_USER -d $DIR -f $POSTGIS/spatial_ref_sys.sql
echo "...done."

# Load excel files
for file in *.xls
do
   echo "loading excel file $file..."
   java -jar $EXCEL2DB -d $DIR -u $DB_USER -w $DB_PW "$file"
   echo "...done."
done

# Change directory
cd $SHAPEFILES || {
   echo "Cannot change to directory $SHAPEFILES">&2
   exit $E_NODIR
}
echo "Go to `pwd`"

# Load shapefiles
for file in *.shp
do
   echo "loading shapefile ${file%".shp"}..."
   $POSTGRES_BIN/shp2pgsql -s ${SRID} -k ${file%".shp"} | $POSTGRES_BIN/psql -U $DB_USER -d $DIR
   echo "...done."
done



